.. _extensions:

Extensions
==========

    See also: :ref:`How to manage extensions <manage-extensions>`

In the context of building a charm, in Rockcraft and Charmcraft, an *extension* is a
name you can pass to the ``extensions`` key of a charm's ``charmcraft.yaml`` file that
will include the usual keys, however, customised for a particular purpose.

An extension is usually associated with a particular :ref:`profile <profile>`.

.. toctree::
    :maxdepth: 2

    django-framework-extension
    express-framework-extension
    fastapi-framework-extension
    flask-framework-extension
    go-framework-extension
    spring-boot-framework-extension
